scipy.sparse.coo
================

.. automodule:: scipy.sparse.coo

   
   
   .. rubric:: Functions

   .. autosummary::
   
      coo_matvec
      coo_tocsr
      coo_todense
      getdtype
      isintlike
      isshape
      isspmatrix
      isspmatrix_coo
      to_native
      upcast
      warn
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      coo_matrix
   
   

   
   
   